require 'spec_helper'

describe Pondize::Convert do
  describe '#pondize' do
    subject(:convert) { Pondize::Convert.new(tonality, sly) }
    subject { convert.pondize }

    context 'accidentals addition' do
      context 'in positive tonality' do
        let(:tonality) { 3 }
        let(:sly) { 'c' }

        it 'appends sharps to notes without accidentals' do
          is_expected.to eq("cs")
        end

        it 'preserves accidentals in same direction' do
          expect(convert.pondize("cs")).to eq("cs")
        end

        it 'preserves accidentals in opposite direction changing to lylipond' do
          expect(convert.pondize("cl")).to eq("cf")
        end

        it 'preserves naturals' do
          expect(convert.pondize("cn")).to eq("c")
        end

        it 'separtes notes with spaces' do
          expect(convert.pondize("clcncdldndsefg")).to eq("cf c cs df d ds e fs gs")
        end

        it 'doesnt create spaces for duration marks' do
          expect(convert.pondize("c4rdb4a")).to eq("cs4 r d b4 a")
        end

        it 'doesnt create spaces for dot marks' do
          expect(convert.pondize("c2.a")).to eq("cs2. a")
        end

        it 'doesnt create spaces for fingerings' do
          expect(convert.pondize("c2-2a")).to eq("cs2-2 a")
        end
      end

      context 'in negative tonality' do
        let(:tonality) { -5 }
        let(:sly) { 'a' }

        it 'appends flats to notes without accidentals' do
          is_expected.to eq("af")
        end
      end
    end
  end
end
